@@ -612,17 +612,15 @@ int yaf_dispatcher_handle(yaf_dispatcher_t *dispatcher, yaf_request_t *request,
 			if (executor) {
 				/* controller's property can override the Dispatcher's */
 				zval rv;
-				int auto_render;
 				render = zend_read_property(ce, executor, ZEND_STRL(YAF_CONTROLLER_PROPERTY_NAME_RENDER), 1, &rv);
-				if (render == &EG(uninitialized_zval)) {
+				if (Z_TYPE_P(render) == IS_NULL) {
 					render = zend_read_property(yaf_dispatcher_ce,
 							dispatcher, ZEND_STRL(YAF_DISPATCHER_PROPERTY_NAME_RENDER), 1, NULL);
 				}
-				auto_render = (Z_TYPE_P(render) == IS_TRUE || (Z_TYPE_P(render) == IS_LONG && Z_LVAL_P(render)));
 
 				instantly_flush	= zend_read_property(yaf_dispatcher_ce,
 						dispatcher, ZEND_STRL(YAF_DISPATCHER_PROPERTY_NAME_FLUSH), 1, NULL);
-				if (auto_render) {
+				if (Z_TYPE_P(render) == IS_TRUE || (Z_TYPE_P(render) == IS_LONG && Z_LVAL_P(render))) {
 					if (Z_TYPE_P(instantly_flush) == IS_FALSE) {
 						zend_call_method_with_1_params(executor, ce, NULL, "render", &ret, &action);
 						zval_ptr_dtor(executor);
